@@ -22,6 +22,7 @@
 #include "ui/resourcesdialogpage.h"
 #include "ui/sounddevicedialogpage.h"
 #include "ui/appearencedialogpage.h"
+#include "ui/exportghnsdialog.h"
 #include "core/resourcemanager.h"
 #include "core/editorsession.h"
 #include "core/resources/courseresource.h"
@@ -31,8 +32,8 @@
 
 #include <KActionCollection>
 #include <KConfigDialog>
-#include <KDeclarative/KDeclarative>
 #include <KLocalizedString>
+#include <KLocalizedContext>
 #include <KMessageBox>
 #include <KNS3/DownloadDialog>
 #include <KStandardAction>
@@ -56,8 +57,8 @@
 using namespace LearnerProfile;
 
 MainWindowEditor::MainWindowEditor()
-    : m_editorSession(new EditorSession(this))
-    , m_resourceManager(new ResourceManager(this))
+    : m_resourceManager(new ResourceManager(this))
+    , m_editorSession(new EditorSession(this))
     , m_widget(new QQuickWidget)
 {
     m_editorSession->setResourceManager(m_resourceManager);
@@ -78,20 +79,17 @@ MainWindowEditor::MainWindowEditor()
     }
     m_resourceManager->loadCourseResources();
 
-    KDeclarative::KDeclarative kdeclarative;
-    kdeclarative.setDeclarativeEngine(m_widget->engine());
-    kdeclarative.setupBindings(); //TODO use result for determining touch/desktop version
-
     // create menu
     setupActions();
 
     // set view
     m_widget->resize(QSize(800, 600));
+    m_widget->rootContext()->setContextObject(new KLocalizedContext(m_widget));
     m_widget->rootContext()->setContextProperty("g_resourceManager", m_resourceManager);
     m_widget->rootContext()->setContextProperty("editorSession", m_editorSession);
 
     // set starting screen
-    m_widget->setSource(QUrl::fromLocalFile(QStandardPaths::locate(QStandardPaths::GenericDataLocation, "artikulate/qml/Editor.qml")));
+    m_widget->setSource(QUrl("qrc:/artikulate/qml/Editor.qml"));
     m_widget->setResizeMode(QQuickWidget::SizeRootObjectToView);
 
     QAction *newAct = KStandardAction::save(this, SLOT(save()), actionCollection());
@@ -124,10 +122,18 @@ ResourceManager * MainWindowEditor::resourceManager() const
 void MainWindowEditor::setupActions()
 {
     QAction *settingsAction = new QAction(i18nc("@item:inmenu", "Configure Artikulate"), this);
-    connect(settingsAction, SIGNAL(triggered()), SLOT(showSettingsDialog()));
+    connect(settingsAction, &QAction::triggered, this, &MainWindowEditor::showSettingsDialog);
     actionCollection()->addAction("settings", settingsAction);
     settingsAction->setIcon(QIcon::fromTheme("configure"));
 
+    QAction *exportAction = new QAction(i18nc("@item:inmenu", "Export GHNS Files"), this);
+    connect(exportAction, &QAction::triggered, [=]() {
+        QPointer<QDialog> dialog = new ExportGhnsDialog(m_resourceManager);
+        dialog->exec();
+    });
+    actionCollection()->addAction("export_ghns", exportAction);
+    exportAction->setIcon(QIcon::fromTheme("document-export"));
+
     KStandardAction::quit(this, SLOT(quit()), actionCollection());
 
     setupGUI(Keys | Save | Create, "artikulateui_editor.rc");
